@@ -1,5 +1,10 @@
-#ifndef __RPCNDR_H__
+#ifndef _RPCNDR_H
+#define _RPCNDR_H
 #define __RPCNDR_H__
+#if __GNUC__ >=3
+#pragma GCC system_header
+#endif
+
 #ifndef __RPCNDR_H_VERSION__
 #define __RPCNDR_H_VERSION__        ( 450 )
 #endif /* __RPCNDR_H_VERSION__ */
@@ -44,6 +49,7 @@ extern "C" {
 #endif
 #define small char
 typedef unsigned char byte;
+typedef unsigned char boolean;
 #define NDRSContextValue(hContext) (&(hContext)->userContext)
 #define cbNDRContext 20
 #define byte_from_ndr(source, target) { *(target) = *(*(char**)&(source)->Buffer)++; }
@@ -192,7 +198,7 @@ typedef struct _MIDL_STUB_MESSAGE {
 	unsigned long *SizePtrLengthArray;
 	void*pArgQueue;
 	unsigned long dwStubPhase;
-	unsigned long Reserved[5];
+	unsigned long w2kReserved[5];
 } MIDL_STUB_MESSAGE,*PMIDL_STUB_MESSAGE;
 #pragma pack(pop)
 typedef void*(__RPC_API *GENERIC_BINDING_ROUTINE)(void*);
@@ -222,6 +228,37 @@ typedef struct _COMM_FAULT_OFFSETS {
 	short CommOffset;
 	short FaultOffset;
 } COMM_FAULT_OFFSETS;
+typedef unsigned long (__RPC_USER *USER_MARSHAL_SIZING_ROUTINE)(unsigned long *,unsigned long,void *);
+typedef unsigned char *(__RPC_USER *USER_MARSHAL_MARSHALLING_ROUTINE)(unsigned long *,unsigned char *,void *);
+typedef unsigned char *(__RPC_USER *USER_MARSHAL_UNMARSHALLING_ROUTINE)(unsigned long *,unsigned char *,void *);
+typedef void (__RPC_USER *USER_MARSHAL_FREEING_ROUTINE)(unsigned long *,void *);
+typedef struct _USER_MARSHAL_ROUTINE_QUADRUPLE {
+	USER_MARSHAL_SIZING_ROUTINE pfnBufferSize;
+	USER_MARSHAL_MARSHALLING_ROUTINE pfnMarshall;
+	USER_MARSHAL_UNMARSHALLING_ROUTINE pfnUnmarshall;
+	USER_MARSHAL_FREEING_ROUTINE pfnFree;
+} USER_MARSHAL_ROUTINE_QUADRUPLE;
+typedef void (__RPC_USER *NDR_NOTIFY_ROUTINE)(void);
+typedef enum _IDL_CS_CONVERT {
+	IDL_CS_NO_CONVERT,
+	IDL_CS_IN_PLACE_CONVERT,
+	IDL_CS_NEW_BUFFER_CONVERT
+} IDL_CS_CONVERT;
+typedef void (__RPC_USER *CS_TYPE_NET_SIZE_ROUTINE)(RPC_BINDING_HANDLE,unsigned long,unsigned long,IDL_CS_CONVERT*,unsigned long*,error_status_t*);
+typedef void (__RPC_USER *CS_TYPE_LOCAL_SIZE_ROUTINE)(RPC_BINDING_HANDLE,unsigned long,unsigned long,IDL_CS_CONVERT*,unsigned long*,error_status_t*);
+typedef void (__RPC_USER *CS_TYPE_TO_NETCS_ROUTINE)(RPC_BINDING_HANDLE,unsigned long,void*,unsigned long,byte*,unsigned long*,error_status_t*);
+typedef void (__RPC_USER *CS_TYPE_FROM_NETCS_ROUTINE)(RPC_BINDING_HANDLE,unsigned long,byte*,unsigned long,unsigned long,void*,unsigned long*,error_status_t*);
+typedef void (__RPC_USER *CS_TAG_GETTING_ROUTINE)(RPC_BINDING_HANDLE,int,unsigned long*,unsigned long*,unsigned long*,error_status_t*);
+typedef struct _NDR_CS_SIZE_CONVERT_ROUTINES {
+	CS_TYPE_NET_SIZE_ROUTINE pfnNetSize;
+	CS_TYPE_TO_NETCS_ROUTINE pfnToNetCs;
+	CS_TYPE_LOCAL_SIZE_ROUTINE pfnLocalSize;
+	CS_TYPE_FROM_NETCS_ROUTINE pfnFromNetCs;
+} NDR_CS_SIZE_CONVERT_ROUTINES;
+typedef struct _NDR_CS_ROUTINES {
+	NDR_CS_SIZE_CONVERT_ROUTINES *pSizeConvertRoutines;
+	CS_TAG_GETTING_ROUTINE *pTagGettingRoutines;
+} NDR_CS_ROUTINES;
 typedef struct _MIDL_STUB_DESC {
 	void*RpcInterfaceInformation;
 	void*(__RPC_API *pfnAllocate)(unsigned int);
@@ -241,6 +278,12 @@ typedef struct _MIDL_STUB_DESC {
 	MALLOC_FREE_STRUCT *pMallocFreeStruct;
 	long MIDLVersion;
 	const COMM_FAULT_OFFSETS *CommFaultOffsets;
+	const USER_MARSHAL_ROUTINE_QUADRUPLE *aUserMarshalQuadruple;
+	const NDR_NOTIFY_ROUTINE *NotifyRoutineTable;
+	ULONG_PTR mFlags;
+	const NDR_CS_ROUTINES *CsRoutineTables;
+	void *Reserved4;
+	ULONG_PTR Reserved5;
 } MIDL_STUB_DESC;
 typedef const MIDL_STUB_DESC *PMIDL_STUB_DESC;
 typedef void*PMIDL_XMIT_TYPE;
@@ -249,7 +292,7 @@ typedef struct _MIDL_FORMAT_STRING {
 	unsigned char Format[1];
 } MIDL_FORMAT_STRING;
 typedef void(__RPC_API *STUB_THUNK)(PMIDL_STUB_MESSAGE);
-typedef long(__RPC_API *SERVER_ROUTINE)();
+typedef long(__RPC_API *SERVER_ROUTINE)(void);
 typedef struct _MIDL_SERVER_INFO_ {
 	PMIDL_STUB_DESC pStubDesc;
 	const SERVER_ROUTINE *DispatchTable;
@@ -463,6 +506,11 @@ void*RPC_ENTRY NdrAllocate(PMIDL_STUB_MESSAGE,unsigned int);
 void RPC_ENTRY NdrClearOutParameters(PMIDL_STUB_MESSAGE,PFORMAT_STRING,void*);
 void*RPC_ENTRY NdrOleAllocate(unsigned int);
 void RPC_ENTRY NdrOleFree(void*);
+unsigned char*RPC_ENTRY NdrUserMarshalMarshall(PMIDL_STUB_MESSAGE,unsigned char*,PFORMAT_STRING);
+unsigned char*RPC_ENTRY NdrUserMarshalUnmarshall(PMIDL_STUB_MESSAGE,unsigned char**,PFORMAT_STRING,unsigned char);
+void RPC_ENTRY NdrUserMarshalBufferSize(PMIDL_STUB_MESSAGE,unsigned char*,PFORMAT_STRING);
+unsigned long RPC_ENTRY NdrUserMarshalMemorySize(PMIDL_STUB_MESSAGE,PFORMAT_STRING);
+void RPC_ENTRY NdrUserMarshalFree(PMIDL_STUB_MESSAGE,unsigned char*,PFORMAT_STRING);
 #ifdef __cplusplus
 }
 #endif
